
#include <stdio.h>
#include <string.h>

#include <serial.h>
#include <mpc5xx/microseconds.h>
#include "target/target_hw.h"
#include "target/cfg.h"
#include "flash_monitor.h"
#include "debugmon.h"
#include "misc.h"
#include "download.h"
#include "targetmem.h"
#include "build_date.h"

int main()
{

  init_hw();

  printf("\nMPC5xx Internal Flash Monitor Loaded\n");

  //if there's any junk in the receive buffer, get rid of it
  while (kbhit() == 0) {
    GetSByte();
  }

  if ((int)&external_rom_size == 0) {
    //This target doesn't have any external ROM; go straight to monitor
    printf("Starting flash monitor...\n");
    flash_monitor_loop();
    return(0);
  }

  printf("Press any key within %0.1f seconds to prevent relocation execution...\n", (float)STARTUP_KEYBOARD_DELAY/1000000.0);
 
  usec_settime(0);
  while (usec_gettime() < STARTUP_KEYBOARD_DELAY) {
    if (kbhit() == 0) {
      flash_monitor_loop();
      //this never returns so we need not worry about getting back here, but
      //  for formality's sake:
      return 0;
    }
  }

  //keyboard wasn't hit; start external relocation
  printf("Starting external relocation execution...\n");
  reloc_exec();

  //Hmm, that returned.  Just start the flash monitor
  printf("Starting flash monitor...\n");
  flash_monitor_loop();

  return(0); //not reached  
}

void flash_monitor_loop()
{  
  char c;
  void (*fn)();

  while (1) {
    //if there's any junk in the receive buffer, get rid of it
    while (kbhit() == 0) {
      GetSByte();
    }
    printf("\n");
    printf("----------------------------------------\n");
    printf("%-30s  %8s\n", monitor_name, monitor_version);
    printf("Built %-34s\n", BUILD_DATE);
    printf("----------------------------------------\n");
    printf("\n");
    printf("1. Debug monitor\n");
    printf("2. Execute application from internal RAM\n");
    printf("3. Execute application from external RAM\n");
    printf("4. Execute application from external flash (directly)\n");
    printf("5. Execute application from external flash (via RAM relocation)\n");
    printf("6. Download application to internal RAM\n");
    printf("7. Download application to external RAM\n");
    printf("8. Download application to external flash\n");
    printf("9. Download application to external flash (for RAM relocation)\n");
    getoption:
    printf("\n");
    printf("Choose an option: ");
    c = tolower(GetSByte());
    printf("%c\n", c);
    switch (c) {
      case '1':
	debugmonloop();
        break;
      case '2':
        fn = (void (*)())&internal_ram_start;
        fn();
        break;
      case '3':
        fn = (void (*)())&external_ram_start;
        fn();
        break;
      case '4':
        fn = (void (*)())&external_rom_start;
        fn();
        break;
      case '5':
        reloc_exec();
        break;
      case '6':
        if (dl_image(DL_INT_RAM, 1) < 0) {
          //failure
        }
        else {
          //success
        }
        break;
      case '7':
        if (dl_image(DL_EXT_RAM, 1) < 0) {
          //failure
        }
        else {
          //success
        }
        break;
      case '8':
        if (dl_image(DL_EXT_ROM, 1) < 0) {
          //failure
        }
        else {
          //success
        }
        break;
      case '9':
        if (dl_image(DL_EXT_RELOC, 1) < 0) {
          //failure
        }
        else {
          //success
        }
        break;
      case '\r':
      case '\n':
        //empty option; try again
        goto getoption;
        break;
      default:
        printf("\nUnknown option.\n");
        break;
    }
  }

  //not reached  
}

void reloc_exec()
{
  void (*fn)();

  printf("Copying external flash to external RAM...");
  //copy contents of flash into RAM
  memcpy((void*)&external_ram_start, (void*)&external_rom_start, MIN((int)&external_rom_size,(int)&external_ram_size));
  printf("done.\n");

  //jump to RAM
  fn = (void (*)())&external_ram_start;
  printf("Jumping to RAM code at %p\n", fn);
  fn();

  printf("RAM code returned!\n");
}

