
#include <Motorola/mpc566.h>
#include <mpc566evb/mpc566evb.h>
#include <mpc566evb/mpc566evb_flash.h>
#include "target_flash.h"
#include "../targetmem.h"

//assumes that external_rom_size is a multiple of 4 (an integral number of
//  words)
int erase_external_rom()
{
  long *ptr;
  long *endptr;

  //This should be completely unnecessary, but is perfectly safe (I think)
  //  and proved useful on at least one occasion
  mpc566evb_flash_reset();
  
  mpc566evb_flash_erase_all_user();

  //The above function calls mpc566evb_flash_reset() before it returns,
  //  so we can go ahead and start reading from the flash

  //That doesn't return a value even though it could possibly detect errors, so
  //  we'll do a quick erasure verification here:

  //The erase command should have reset all bits of the flash to '1'

  endptr = (long*)(((char*)&external_rom_start)+(int)&external_rom_size);

  for (ptr = (long*)&external_rom_start; ptr < endptr; ptr++) {
    if (*ptr != 0xffffffff) {
      //unasserted bits found!  Erase must have failed
      return -1;
    }
  }

  return 0;
}

int write_external_rom(unsigned int *dest, unsigned int *src, int size)
{
  int i;

  for (i = 0; i < size; i++) {
    mpc566evb_flash_write_word(dest+i, src[i]);
  }

  //In order to verify the data written, we need to have the flash in read mode
  //  which requires a reset.  If it failed during the above call, we've
  //  reset (which is OK).  This is possibly unpleasant overhead, but verifying
  //  every block as it's written makes life easy.
  mpc566evb_flash_reset();

  for (i = 0; i < size; i++) {
    if (dest[i] != src[i]) {
      //mismatch; write must have failed!
      return -1;
    }
  }

  return 0;
}

int reset_external_rom()
{
  //we probably don't need to do this because the above functions call this as
  //  necessary, but it can't hurt
  mpc566evb_flash_reset();

  //hopefully not much can fail here; just assume it worked
  return 0;
}

