//
// internal_flash_loader.c : boot loader to run from RAM and write a ROM image to internal MPC566 flash
//
/****************************************************************/
#include <string.h>
#include <malloc.h>
#include <math.h>

#include <mpc566evb/use_default_serial_port.h>
#include <mpc566evb/C3F_FLASH.h>
#include <Motorola/mpc566.h>

// These will be defined when this is linked with the ROM image to be burned.
extern unsigned char _rom_image_start, _rom_image_end;

/****************************************************************/
// This is the entry point called by crt0.S.
main (void)
{
  int delaycount;
  int wait;
  UINT32 error;

  //The memory controller, clock rate, and baud rate are already set

  use_default_serial_port();
  clear_bss_section();

  printf("Internal flash loader starting up.\r\n");
  printf("The ROM image begins at %p and ends at %p\r\n", &_rom_image_start, &_rom_image_end);
  printf("\r\n");

  printf("Starting programming after printing 10 periods: \r\n");
  for (delaycount = 0; delaycount < 10; delaycount++ ) {
    for (wait = 0; wait < 250000; wait++) ;
    putch('.');
  }
  printf("\r\n");

  printf("beginning C3F erase...\r\n");
  error = C3F_flash_erase();
  printf("C3F driver returned 0x%x from erase.\r\n", error);

  if (error == 0) {
    printf("beginning C3F write..\r\n");

    error = C3F_flash_write( (UINT32 *) 0,  // dest
			     (UINT32 *) &_rom_image_start, 
			     &_rom_image_end - &_rom_image_start );

    printf("C3F driver returned 0x%x from write.\r\n", error);  
  }
  printf( "Internal flash loader is done, entering tight loop.\r\n" );
  while (1);
}
