/**************************************************************************/
/* FILE NAME: tpu_dio.h                       COPYRIGHT (c) MOTOROLA 2002 */
/* VERSION: 1.0                                   All Rights Reserved     */
/*                                                                        */
/* DESCRIPTION: This file defines the interface to the TPU DIO functions  */
/* and provides useful #defines.                                          */
/*                                                                        */
/*========================================================================*/
/* HISTORY           ORIGINAL AUTHOR: Jeff Loeliger                       */
/* REV      AUTHOR      DATE       DESCRIPTION OF CHANGE                  */
/* ---   -----------  ---------    ---------------------                  */
/* 1.0   J. Loeliger  19/Aug/02    Initial version of function.           */
/**************************************************************************/
#ifndef _TPU_DIO_H
#define _TPU_DIO_H

#include "m_common.h"
#include "m_tpu3.h"

/* Define pin state */
#define TPU_DIO_PIN_HIGH 1
#define TPU_DIO_PIN_LOW  0

/* Configuration values */
#define TPU_DIO_RISING_EDGE  0x07
#define TPU_DIO_FALLING_EDGE 0x0B
#define TPU_DIO_BOTH_EDGES   0x0F
#define TPU_DIO_TCR1         0x03
#define TPU_DIO_TCR2         0x23

/* TPU DIO function prototypes */
void tpu_dio_init_output(struct TPU3_tag *tpu, UINT8 channel, UINT8 priority,\
            UINT8 level);
void tpu_dio_init_input_trans(struct TPU3_tag *tpu, UINT8 channel, \
            UINT8 priority, UINT8 mode);
void tpu_dio_init_input_periodic(struct TPU3_tag *tpu, UINT8 channel, \
            UINT8 priority, UINT8 tcr, UINT16 rate);
void tpu_dio_init_input_immed(struct TPU3_tag *tpu, UINT8 channel, UINT8 priority);

void tpu_dio_output_high(struct TPU3_tag *tpu, UINT8 channel);
void tpu_dio_output_low(struct TPU3_tag *tpu, UINT8 channel);
void tpu_dio_output(struct TPU3_tag *tpu, UINT8 channel, UINT8 level);
UINT16 tpu_dio_input_immed(struct TPU3_tag *tpu, UINT8 channel);
UINT16 tpu_dio_pin_history(struct TPU3_tag *tpu, UINT8 channel);

/* The #defines below here are normally only used internally by the */
/* DIO API functions and should not be needed in user programs.     */

/* Define HSR values */
#define TPU_DIO_INIT       0x3
#define TPU_DIO_FORCE_LOW  0x2
#define TPU_DIO_FORCE_HIGH 0x1

/* Define HSQ values */
#define TPU_DIO_TRANS_MODE 0x0
#define TPU_DIO_MATCH_MODE 0x1
#define TPU_DIO_IMMED_MODE 0x2

/* Define parameter RAM locations */
#define TPU_DIO_CHANNEL_CONTROL 0
#define TPU_DIO_PIN_LEVEL       1
#define TPU_DIO_MATCH_RATE      2

#endif /* ifndef _TPU_DIO_H  */

/*********************************************************************
 *
 * Copyright:
 *	MOTOROLA, INC. All Rights Reserved.  
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of Motorola, Inc. This 
 *  software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, MOTOROLA 
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED, INCLUDING 
 *  IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 *  PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH REGARD TO THE 
 *  SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF) AND ANY 
 *  ACCOMPANYING WRITTEN MATERIALS.
 * 
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL MOTOROLA BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING 
 *  WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS 
 *  INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY
 *  LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.   
 * 
 *  Motorola assumes no responsibility for the maintenance and support
 *  of this software
 ********************************************************************/

