/**************************************************************************/
/* FILE NAME: tpu_qom_example3.c              COPYRIGHT (c) MOTOROLA 2002 */
/* VERSION: 1.1                                   All Rights Reserved     */
/*                                                                        */
/* DESCRIPTION: This sample program shows a simple example of a program   */
/* that uses the QOM API to control an output pin.                        */
/* The program is targeted for the MPC555 but should work on any MPC500   */
/* device with a TPU. For other devices the setup routines will also need */
/* to be changed.                                                         */
/*========================================================================*/
/* HISTORY           ORIGINAL AUTHOR: Jeff Loeliger                       */
/* REV      AUTHOR      DATE       DESCRIPTION OF CHANGE                  */
/* ---   -----------  ---------    ---------------------                  */
/* 1.0   J. Loeliger  27/Sep/02    Initial version of function.           */
/* 1.1   J. Loeliger  13/Dec/02    Added while(1) to end code.            */
/**************************************************************************/

#include "mpc555.h"     /* Define all of the MPC555 registers, this needs to */
                        /* changed if other MPC500 devices are used.         */
#include "mpc500.c"     /* Configuration routines for MPC555 EVB, will need */
                        /* to be changed if other hardware is used.         */
#include "mpc500_util.h"    /* Utility routines for using MPC500 devices */
#include "tpu_qom.h"    /* TPU qom functions */

union event_tag event[2]; /* 3 events */

void main ()
{
     struct TPU3_tag *tpua = &TPU_A;   /* pointer for TPU routines */
    
     setup_mpc500(40);       /*Setup device and program PLL to 40MHz*/	

/********************************************************************/
/* Define output: 3 edges (low, high, low)                          */
/* channel: 4                                                       */
/* mode: single shot                                                */
/* timebase: TCR1                                                   */
/* initial pin state: high                                          */
/* first match: from reference                                      */
/* loop count: NA (not used in single shot match mode)              */
/* reference parameter: channel 6 parameter 2                       */
/* number of events: 3                                              */
/* event 1: $1000 counts then drive pin low.                        */
/* event 2: $0280 counts then drive pin high.                       */
/* event 3: $3000 counts then drive pin low .                       */
/********************************************************************/
    
    event[0].p = (0x1000 << 1) + TPU_QOM_FALLING_EDGE;
    event[1].p = (0x0280 << 1) + TPU_QOM_RISING_EDGE;
    event[2].p = (0x3000 << 1) + TPU_QOM_FALLING_EDGE;

    tpu_qom_init(tpua, 4, TPU_PRIORITY_HIGH, TPU_QOM_SINGLE_SHOT,\
        TPU_QOM_TCR1, TPU_QOM_INIT_PIN_HIGH, TPU_QOM_REF,\
        0, 0x62, 3, event);

    while(1);

}

/*********************************************************************
 *
 * Copyright:
 *	MOTOROLA, INC. All Rights Reserved.  
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of Motorola, Inc. This 
 *  software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, MOTOROLA 
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED, INCLUDING 
 *  IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 *  PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH REGARD TO THE 
 *  SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF) AND ANY 
 *  ACCOMPANYING WRITTEN MATERIALS.
 * 
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL MOTOROLA BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING 
 *  WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS 
 *  INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY
 *  LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.   
 * 
 *  Motorola assumes no responsibility for the maintenance and support
 *  of this software
 ********************************************************************/

