/***************  gmd_C3F.h  ********************************************

FUNCTION: Defines and prototypes for Motorola GMD flash drivers

 VERSION: 2000.12.05 Chuck Kuecker (www.RickMiller.com)
          2001.01.10 CK mods to meet updated requirements
          2001.02.11 Rick Miller removed tabs.
          2001.02.13 Rick Miller added FLASHID error
          2001.10.29 Jiazheng Shi update to fit MPC56x with C3F

   NOTES:
     USE:
*/

#ifndef GMD_C3F
#define GMD_C3F

/* Return codes */

typedef enum
{
   C3F_OK                             = 0x00000000,
   C3F_INFO_LOCK_B                    = 0x00000001,
   C3F_INFO_LOCK_A                    = 0x00000002,
   C3F_INFO_EPEE_B                    = 0x00000004,
   C3F_INFO_EPEE_A                    = 0x00000008,
   C3F_INFO_BOEPEE_B                  = 0x00000010,
   C3F_INFO_BOEPEE_A                  = 0x00000020,
   C3F_INFO_HVS_B                     = 0x00000040,
   C3F_INFO_HVS_A                     = 0x00000080,
   C3F_INFO_CENSOR_B                  = 0x00000100,
   C3F_INFO_CENSOR_A                  = 0x00000200,
   C3F_INFO_STOP_B                    = 0x00000400,
   C3F_INFO_STOP_A                    = 0x00000800,
   C3F_INFO_FLEN                      = 0x00001000,
   C3F_INFO_FLASHID                   = 0x00002000,
   C3F_ERROR_INVALID_ENABLED_BLOCK    = 0x00004000,
   C3F_UNUSED_FLAG3                   = 0x00008000,
   C3F_UNUSED_FLAG4                   = 0x00010000,
   C3F_ERROR_PARTID	                  = 0x00020000,
   C3F_ERROR_ALIGNMENT                = 0x00040000,
   C3F_ERROR_SHADOW_RANGE             = 0x00080000,
   C3F_ERROR_ARRAY_RANGE              = 0x00100000,
   C3F_ERROR_ENABLED_SMALL_BLOCK      = 0x00200000,
   C3F_ERROR_ERASE_PEGOOD             = 0x00400000,
   C3F_ERROR_PROGRAM_VERIFICATION     = 0x00800000,
   C3F_ERROR_PROGRAM_PEGOOD           = 0x01000000,
   C3F_ERROR_NOT_BLANK                = 0x02000000,
   C3F_ERROR_SRC_DEST_VERIFY          = 0x04000000,
   C3F_ERROR_CENSOR_MODULE            = 0x08000000,
   C3F_ERROR_CENSOR_VALUE             = 0x10000000,
   C3F_ERROR_CENSOR_DEVICE_MODE       = 0x20000000,
   C3F_ERROR_CENSOR_INVALID_REQUEST   = 0x40000000,
   C3F_ERROR_CENSOR_PEGOOD            = 0x80000000
}C3F_RESULT;


/* Driver prototypes */

C3F_RESULT BlankCheck ( UINT8 enabledBDM,
                void (*CallBack)(void),
                UINT32 dest,
                UINT32 size,
                UINT32 *compareAddress,
                UINT32 *compareData,
                UINT32 arrayBase
                );


C3F_RESULT ChangeCensor ( UINT8 enabledBDM,
                void(*CallBack)(void),
                UINT8 module ,
                UINT8 censorValue,
                UINT8 deviceMode,
                UINT32 arrayBase
                );


C3F_RESULT FlashErase ( UINT8 enabledBDM,
                void (*CallBack)(void),
                UINT8 enabledBlock[],
                UINT8 enabledSBlock[],
                UINT32 arrayBase
                );


C3F_RESULT FlashVerify (UINT8 enabledBDM,
                void (*CallBack)(void),
                UINT32 dest,
                UINT32 size,
                UINT32 source,
                UINT32 *compareAddress,
                UINT32 *compareData,
                UINT32 *compareSourceData,
                UINT32 arrayBase
                );


C3F_RESULT FlashProgram (UINT8 enabledBDM,
                 void(*CallBack)(void),
                 UINT32 dest,
                 UINT32 size,
                 UINT32 source,
                 UINT32 arrayBase
                 );

C3F_RESULT CheckSum (UINT8 enabledBDM,
                 void(*CallBack)(void),
                 UINT32 dest,
                 UINT32 size,
                 UINT32 *sum,
                 UINT32 arrayBase
                 );

C3F_RESULT FlashInit(UINT8 enabledBDM,
                 UINT32 *arrayPointer);

C3F_RESULT FlashCheckShadow(UINT8 enabledBDM,
                 BOOL shadow,
                 UINT32 dest,
                 UINT32 size,
                 UINT32 arrayBase
                 );

#endif

/*  End of gmd_C3F.h */