// Interface for the new ppc board
#ifndef __NEWFILE_H_INCLUDED_
#define __NEWFILE_H_INCLUDED_

#include "/home/MPC5xx/libMotorola/mpc566.h"
#include "/home/MPC5xx/libMotorola/mpc500_util.h"
#include "/home/MPC5xx/libMotorola/tpu_siop.h"
#include "/home/MPC5xx/libMotorola/tpu_dio.h"
#include "/home/MPC5xx/libmpc566evb/mpc566evb.h"
#include <mpc5xx/memutils.h>
#include <mpc5xx/microseconds.h>
#include <mpc5xx/timestamps.h>

#include <stdio.h>
#include <serial.h>
#include <stdlib.h>
#inlucde "rt_626.h"

//Values are scaled so that [-1,1] maps over the maximum negative
// to maximum positive torque range, with 0.0 = 0.0 torque
typedef struct {        // Commands fora  single leg
  float hipx;           // hip torque command, oriented around x axis
  float hipy;           // hip torque command, oriented around y axis
  float knee;
} bio_leg_tau_t;

typedef struct {        // commands for entire biped
  // float torso;       // torso rotation torque wrt body (around z axis)
  bio_leg_tau_t left;      // left leg commands
  bio_leg_tau_t right;      // right leg commands
} bio_tau_t;

// Set up the serial channels
extern void init_serial_ports(void);

// Set up the digital channels
extern void init_digital_ports(void);

// Set the output torques. This sets up the serial ports and begins
// transmitting data to the D/A converters
extern void bio_write_tau(bio_tau_t *tau);

// Test if the serial port has finished streaming data to the D/A 
// converters.
extern int bio_write_tau_complete(bio_tau_t *tau);

// Finish the D/A converter transaction, posting the result to the 
// output stage.
extern void bio_update_dac(void);

// trigger the torque sense inputs analog conversion.
extern void bio_read_tau_sense(bio_tau_t *tau);

// Test if the torque sense conversion is complete.
extern int bio_read_tau_sense_complete(void);

// Read the torque sense inputs, copied into the user supplied buffer.
// The values should be scaled as for the torque outputs, [-1,1] = [max neg, max pos]
// sense signal.  (This will likely also be scaled by a calibration factor in the 
// higher-level code.)
extern void bio_read_tau_sense(bio_tau_t *tau_sense);

// The motor codes used for the following functions are as follows:
#define BIO_MOTOR_LHY    0x01     // left hip pitch
#define BIO_MOTOR_LK     0x02     // left knee
#define BIO_MOTOR_RHY    0x04     // right hip pitch
#define BIO_MOTOR_RK     0x08     // right knee

// #define BIO_MOTOR_TORSO    0x10     // torso

#define BIO_MOTOR_LHX    0x20     // left hip roll
#define BIO_MOTOR_LRX    0x40     // right hip roll
#define BIO_MOTOR_MASK   0x7f     // define a mask for all bits used by motor flags
#define BIO_MOTOR_BITS   7     // define the number of buts used by motor flags

// Reset motor drivers after a fault. A "1" means the corresponding motor drivers
// reset their fault latches and disable their output stages.  A "0" will allow 
// normal opertaion.  The but patterns are defined by the motor codes above.
extern void bio_reset_drivers(unsigned short value);

// Enable the output stage of motor drivers. A "1" means the corresponding motor 
// drivers will enable their output stages (unless a fault has been latched). 
// A "0" means the driver will allow the motor to freewheel (i.e., no braking).
// The bit positions are defined by the motor codes above.
extern void bio_enable_drivers(unsigned short value);

// Read the fault state of the motor drivers.  A "1" means the correspnding motor
// drivers are indicating a fault state.  The bit postions are defined by the motor 
// codes above.
extern unsigned short bio_read_driver_fault(void);

// Set the indecator LEDS.  A "1" means the corresponding LED is on.
// The bit positions are defined by the motor codes above.
extern viod bio_set_LEDS(unsinged short value);


#endif // __NEWFILE_H_INCLUDED_

