/**************************************************************************/
/* FILE NAME: tpu_pwm.h                       COPYRIGHT (c) MOTOROLA 2002 */
/* VERSION:  0.1                                  All Rights Reserved     */
/*                                                                        */
//* DESCRIPTION:                                                          */
/* This file defines all of the registers and bit fields on the TPU3      */
/* Pulse Width Modulation (PWM) function.                                  */
/*========================================================================*/
/* AUTHOR: Randy Dees                                                     */
/* COMPILER: Diab Data        VERSION: 4.3g                               */
/*                                                                        */
/* HISTORY                                                                */
/* REV      AUTHOR      DATE        DESCRIPTION OF CHANGE                 */
/* ---   -----------  ----------    ---------------------                 */
/* 0.1   R. Dees      09/Oct/02    Initial version for PWM               */
/*                                                                        */
/**************************************************************************/

#include "m_tpu3.h"

#ifdef  __cplusplus
extern "C" {
#endif

/*************************************************************/
/*            Definition of terms and initial settings       */
/*************************************************************/

/* Define HSQ values (mode) */
/* HSQ values are not used by the PWM function. */

/* Define the Immediate values */
#define TPU_PWM_NORMAL 0x0	/* Update normally at end of next cycle */
#define TPU_PWM_IMMED 0x1	/* Update values immediately */
#define TPU_PWM_IMMED_MASK 0x1 /* MASK for illegal values */

/* State Definitions */
#define TPU_PWM_LOW	0x0
#define TPU_PWM_HIGH	0x1

/* Define HSR values */
#define TPU_PWM_NO_HOST 	0x0	/* No Host Service (Reset Condition) */ 
#define TPU_PWM_IMMED_UPDATE	0x1	/* Update PWM parameters immediately */
#define TPU_PWM_INIT 		0x2	/* Initialize  */
#define TPU_PWM_NOT_USED_3	0x3	/* Not Used */


/* Define test result values */
#define TPU_PWM_TRUE  1
#define TPU_PWM_FALSE 0

/* Define TPU_Channel Control. PSC is always 0b1 (start high) */
#define TPU_PWM_PSC	0x1
#define TPU_PWM_PSC_MASK 0x3
/* PSC is always 0b1xx (shift by 2 for channel control location */
#define TPU_PWM_PAC 0x10
#define TPU_PWM_PAC_MASK 0x7

/* Define the Timer values */
#define TPU_PWM_TCR1	4	/* Capture TCR1, Match TCR1 */
#define TPU_PWM_TCR2	7	/* Capture TCR2, Match TCR2 */
#define TPU_PWM_TBS_MASK 0xF


/* Define parameter RAM locations */
#define TPU_PWM_CHANEL_CONTROL	0	/* Channel Control TCR1 or 2 */
#define TPU_PWM_OLDRIS			1	/* Old Rise time - used by TPU */
#define TPU_PWM_PWMHI			2	/* High time of the period */
#define TPU_PWM_PWMPER			3	/* Period */
#define TPU_PWM_PWMRIS			4	/* Next rise time */
#define TPU_PWM_PRM_5			5	/* Not Used */
#define TPU_PWM_PRM_6			6	/* Not Used */
#define TPU_PWM_PRM_7			7	/* Not Used */

/* define 32-bit parameter RAM Location for accessing */
#define TPU_PWM_HIPER32	1 /* the high time and period together */

/* Prototype of functions */

void tpu_pwm_init(struct TPU3_tag *tpu, UINT8 channel, 
		UINT8 priority, UINT16 period, UINT16 hightime, UINT8 timer);

void tpu_pwm_update(struct TPU3_tag *tpu, UINT8 channel, 
		UINT16 period, UINT16 hightime, UINT8 immediate);

void tpu_pwm_force(struct TPU3_tag *tpu, UINT8 channel, UINT8 state);

UINT16 tpu_pwm_get_period(struct TPU3_tag *tpu, UINT8 channel);

UINT16 tpu_pwm_get_hightime(struct TPU3_tag *tpu, UINT8 channel);

void setup_tpu(struct TPU3_tag *tpu);

#ifdef  __cplusplus
}
#endif


/*********************************************************************
 *
 * Copyright:
 *	MOTOROLA, INC. All Rights Reserved.  
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of Motorola, Inc. This 
 *  software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, MOTOROLA 
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED, INCLUDING 
 *  IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 *  PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH REGARD TO THE 
 *  SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF) AND ANY 
 *  ACCOMPANYING WRITTEN MATERIALS.
 * 
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL MOTOROLA BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING 
 *  WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS 
 *  INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY
 *  LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.   
 * 
 *  Motorola assumes no responsibility for the maintenance and support
 *  of this software
 ********************************************************************/


