/**************************************************************************/
/* FILE NAME: tpu_qdec_exmaple2.c             COPYRIGHT (c) MOTOROLA 2002 */
/* VERSION: 1.0                                   All Rights Reserved     */
/*                                                                        */
/* DESCRIPTION: This sample program show a simple example of a program    */
/* that uses the discrete input/transition counter feature of the QDEC    */
/* function. The signal is connected to channel 12 on TPU B. The number of*/
/* transistions and other data is continually read from the channel.      */
/* The program is targeted for the MPC555 but should work on any MPC500   */
/* device with a TPU. For other devices the setup routines will also need */
/* to be changed.                                                         */
/*========================================================================*/
/* HISTORY           ORIGINAL AUTHOR: Jeff Loeliger                       */
/* REV      AUTHOR      DATE       DESCRIPTION OF CHANGE                  */
/* ---   -----------  ---------    ---------------------                  */
/* 1.0   J. Loeliger  11/Aug/02    Initial version of function.           */
/**************************************************************************/

#include "mpc555.h"     /* Define all of the MPC555 registers, this needs to */
                        /* changed if other MPC500 devices are used.         */
#include "mpc500.c"     /* Configuration routines for MPC555 EVB, will need */
                        /* to be changed if other hardware is used.         */
#include "mpc500_util.h"    /* Utility routines for using MPC500 devices */
#include "tpu_qdec.h"   /* TPU QDEC functions */

INT16 count;     /* global transistion counter */

void main ()
{
     struct TPU3_tag *tpub = &TPU_B;   /* pointer for TPU routines */
     INT16 tcr1;          /* current TCR1 value */
     INT16 edge;          /* last edge time */
     INT16 primary_pin;   /* current pin state */
     INT16 junk;          /* this varible is not used and will return junk */
    
     setup_mpc500(40);       /*Setup device and programm PLL to 40MHz*/	

    /* Initialize transistion count feature with:   */
    /*    -Input signal on TPU B channel 12         */
    /*    -Schedule as low priority in the TPU      */
    tpu_qdec_init_trans_count( tpub, 12 , TPU_PRIORITY_LOW);
    
    while (1) {
         count = tpu_qdec_position ( tpub, 12 );
         
         tpu_qdec_data( tpub, 12 , &tcr1, &edge, &primary_pin, &junk);
    }
}

/*********************************************************************
 *
 * Copyright:
 *	MOTOROLA, INC. All Rights Reserved.  
 *  You are hereby granted a copyright license to use, modify, and
 *  distribute the SOFTWARE so long as this entire notice is
 *  retained without alteration in any modified and/or redistributed
 *  versions, and that such modified versions are clearly identified
 *  as such. No licenses are granted by implication, estoppel or
 *  otherwise under any patents or trademarks of Motorola, Inc. This 
 *  software is provided on an "AS IS" basis and without warranty.
 *
 *  To the maximum extent permitted by applicable law, MOTOROLA 
 *  DISCLAIMS ALL WARRANTIES WHETHER EXPRESS OR IMPLIED, INCLUDING 
 *  IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR
 *  PURPOSE AND ANY WARRANTY AGAINST INFRINGEMENT WITH REGARD TO THE 
 *  SOFTWARE (INCLUDING ANY MODIFIED VERSIONS THEREOF) AND ANY 
 *  ACCOMPANYING WRITTEN MATERIALS.
 * 
 *  To the maximum extent permitted by applicable law, IN NO EVENT
 *  SHALL MOTOROLA BE LIABLE FOR ANY DAMAGES WHATSOEVER (INCLUDING 
 *  WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS 
 *  INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY
 *  LOSS) ARISING OF THE USE OR INABILITY TO USE THE SOFTWARE.   
 * 
 *  Motorola assumes no responsibility for the maintenance and support
 *  of this software
 ********************************************************************/

