#ifndef _TPU_SIOP_H_
#define _TPU_SIOP_H_

#include "m_common.h"
#include "m_tpu3.h"

/* operating modes (HSQ values) */
#define TPU_SIOP_CLOCK_ONLY	0x0
#define TPU_SIOP_TX_ONLY	0x1
#define TPU_SIOP_RX_ONLY	0x2
#define TPU_SIOP_BIDIRECTIONAL	0x3

#define TPU_SIOP_MODE_MASK 0x3

/* operating states (HSR values) */
#define TPU_SIOP_STOP	0x0
#define TPU_SIOP_START	0x3

#define TPU_SIOP_STARTMODE_MASK 0x3

/* clock polarity */
#define TPU_SIOP_NEGEDGE_CLOCK 0x008D
#define TPU_SIOP_POSEDGE_CLOCK 0x008E

/* shift direction */
#define TPU_SIOP_LSB_FIRST 0x0
#define TPU_SIOP_MSB_FIRST 0x1

/* whether to enable interrupts */
#define TPU_SIOP_NOINTERRUPT	0x0
#define TPU_SIOP_INTERRUPT	0x1

/* parameter RAM locations */
#define TPU_SIOP_DIRECTION_POLARITY	0x0 /* includes BIT_D AND CHANNEL_CONTROL */
#define TPU_SIOP_BIT_D		0x0
#define TPU_SIOP_CHAN_CONTROL	0x0
#define TPU_SIOP_HALF_PERIOD	0x1
#define TPU_SIOP_BIT_COUNT	0x2
#define TPU_SIOP_XFER_SIZE	0x3
#define TPU_SIOP_DATA		0x4

#define TPU_SIOP_BIT_D_MASK		0x1
#define TPU_SIOP_BIT_D_SHIFT		15
#define TPU_SIOP_CHAN_CONTROL_MASK	0x01FF
#define TPU_SIOP_CHAN_CONTROL_SHIFT	0
#define TPU_SIOP_BIT_COUNT_MASK		0x0F
#define TPU_SIOP_XFER_SIZE_MASK		0x1F

/* TPU SIOP function prototypes */
void tpu_siop_init(struct TPU3_tag *tpu, UINT8 channel, UINT8 priority,
                   UINT8 mode, UINT16 polarity, UINT8 direction,
                   UINT16 baud_rate, UINT8 size, UINT16 data,
                   UINT8 startmode, UINT8 nointerrupt_interrupt);
void tpu_siop_write_transmit_data(struct TPU3_tag *tpu, UINT8 channel,
                                  UINT16 transmit_data, int cont);
UINT16 tpu_siop_read_receive_data(struct TPU3_tag *tpu, UINT8 channel,
                                  int cont);
UINT16 tpu_siop_service_read_write(struct TPU3_tag *tpu, UINT8 channel,
                                   UINT16 transmit_data, int cont);
void tpu_siop_start_transfer(struct TPU3_tag *tpu, UINT8 channel);

#endif /* _TPU_SIOP_H_ */

