// Abstract datatypes to describe a generic ethernet port, and
// various ethernet data types.  This was reverse-engineered from
// the lan91c111 driver, since it didn't include the higher-level
// type definitions.
// 
// This also defines the board address for the MPC566EVB hardware.

#ifndef __ETHERNET_H_DEFINED__
#define __ETHERNET_H_DEFINED__

#include "netbuf.h"
#include <mpc566evb/mpc566evb.h>

// Hardware address specification.
#define __ETHERNET ((uint8 *)(MPC566EVB_ETHERNET_BASE))

typedef UINT8 *HWA_ADDR_P;   // MAC address pointer

/****************************************************************/
// Abstract definition of an ethernet port.

typedef struct ethernet_port_t {

  // This is provided by the user process:
  unsigned char hwa[6];

  // These are provided by the user process:
  void (*irq_disable)(void);
  void (*irq_enable)(void);
  int (*protocol_exists)   ( struct ethernet_port_t *nif, int type );
  void (*protocol_handler) ( struct ethernet_port_t *nif, int type , netbuf *pNbuf);

  // These are initialized by the driver:
  short mtu;
  int vector;
  short hwa_size;
  int f_tx, f_rx;

  // These are callbacks provided by the driver:
  int	(*reset) (struct ethernet_port_t *);
  void	(*start) (struct ethernet_port_t *);
  void	(*stop) (struct ethernet_port_t *);
  int	(*send) (struct ethernet_port_t *, HWA_ADDR_P, HWA_ADDR_P, UINT16, netbuf*);
  void	(*receive) ( struct ethernet_port_t * );
  netbuf *(*rx_alloc)(void);
  netbuf *(*tx_alloc)(void);
  void (*tx_free)(netbuf *);
  void (*rx_free)(netbuf *);

} ethernet_port;

/****************************************************************/
// The header offset is zero, since we just accept full ethernet
// packets with ethernet frame in the receive buffer.  I.e., the
// first byte of the data area of a netbuf is the beginning of a
// eth_frame_hdr structure.
#define ETH_HDR_OFFSET 0   

// The header size is zero, since when transmitting the packet buffer
// just holds the IP packet, and the parameters for ethernet frame are
// passed as arguments to the send function.
#define ETH_HDR_SIZE 0

#define ETH_MIN_SIZE 60
#define ETH_HWA_LEN 6    // standard 6 byte hardware MAC address length

typedef struct {
  unsigned char dest[ ETH_HWA_LEN ];
  unsigned char src [ ETH_HWA_LEN ];
  unsigned short type;

  // followed by data, minimum of 46 octets, max of 1500
  unsigned char data[46];
  
} eth_frame_hdr;


#ifndef TRUE
#define TRUE 1
#endif

#ifndef FALSE
#define FALSE 0
#endif



#endif
