// A simplified definition of Internet Protocol packets, cobbled
// together from various sources, especially linux kernel
// headers.

#ifndef __IP_H_DEFINED__
#define __IP_H_DEFINED__


// taken from include/netinet/ip.h
struct ip
  {
#if BYTE_ORDER == LITTLE_ENDIAN
    unsigned int ip_hl:4;		/* header length */
    unsigned int ip_v:4;		/* version */
#elif BYTE_ORDER == BIG_ENDIAN
    unsigned int ip_v:4;		/* version */
    unsigned int ip_hl:4;		/* header length */
#else
#error "please define BYTE_ORDER"
#endif

    UINT8 ip_tos;			/* type of service */
    UINT16 ip_len;			/* total length */
    UINT16 ip_id;			/* identification */
    UINT16 ip_off;			/* fragment offset field */
#define	IP_RF 0x8000			/* reserved fragment flag */
#define	IP_DF 0x4000			/* dont fragment flag */
#define	IP_MF 0x2000			/* more fragments flag */
#define	IP_OFFMASK 0x1fff		/* mask for fragmenting bits */

    UINT8 ip_ttl;			/* time to live */
    UINT8 ip_p;			        /* protocol */
    UINT16 ip_sum;			/* checksum */
    UINT32 ip_src, ip_dst;	        /* source and dest address */
  };


// from include/netinet/udp.h
struct udphdr {
  UINT16	source;
  UINT16	dest;
  UINT16	len;
  UINT16	check;
};

// The protocol number in the Ethernet header.
#define ETH_P_IP	0x0800		/* Internet Protocol packet	*/
#define ETH_P_ARP	0x0806		/* Address Resolution packet	*/

// The UDP protocol number in the IP header.
#define UDP_IP_PROTOCOL 17

// Since I'm defining this specifically for a big-endian PowerPC, can define no-ops here:
#if BYTE_ORDER == BIG_ENDIAN
#define htons(v) (v)
#define htonl(v) (v)
#define htonf(v) (v)

#define ntohs(v) (v)
#define ntohl(v) (v)
#define ntohf(v) (v)
#endif


// Define the maximum UDP data payload, assuming a default ethernet MTU of 1500.
// Note that nbuf.h defines it's own limits on packet buffer size.
#define MAX_UDP_DATA (1500 - sizeof(struct udphdr) - sizeof(struct ip))

// Define the full packet layout for a UDP/IP packet.
typedef struct {
  struct ip IP_header;
  struct udphdr UDP_header;
  char data[MAX_UDP_DATA];
} UDP_packet;


#endif __IP_H_DEFINED__
