
#include "interrupts.h"

/* This assumes that we can access the global symbols present in the
   in-RAM data segment of the flash monitor in internal ROM */

int mpc5xx_install_interrupt_handler(mpc5xx_interrupt_t type,
                                     void(*fn)())
{
  switch (type) {
    case MPC5XX_MACHINE_CHECK_INTR:
      machine_check_interrupt_routine = fn;
      break;
    case MPC5XX_EXTERNAL_INTR:
      external_interrupt_routine = fn;
      break;
    case MPC5XX_DECREMENTER_INTR:
      decrementer_interrupt_routine = fn;
      break;
    case MPC5XX_TRACE_INTR:
      trace_interrupt_routine = fn;
      break;
    default:
      //unknown interrupt type
      return -1;
      break;
  }

  return 0;
}

void mpc5xx_install_default_interrupt_handlers()
{
  void(*fn)() = null_interrupt_handler;
 
  machine_check_interrupt_routine = fn;
  external_interrupt_routine = fn;
  decrementer_interrupt_routine = fn;
  trace_interrupt_routine = fn;
}

//return MSR[EE]
int mpc5xx_ext_interrupts_enabled()
{
  int msr;

  asm("mfmsr %0" : "=r" ((msr)));

  return((msr >> 15) & 1);
}

void mpc5xx_enable_external_interrupts()
{

  asm("mtspr 80,%r0");

//Agonizing way that can be prone to problems if we're interrupted:
//  asm("mfmsr %%r3;
//       ori %%r3,%%r3,0x00008000;
//       mtmsr %%r3"
//      : /* outputs */
//      : /* inputs */
//      : "%r3" /* overwrites */
//     );
}

void mpc5xx_disable_external_interrupts()
{

  asm("mtspr 81,%r0"); //mtspr EID,%r0

//Agonizing way that can be prone to problems if we're interrupted:
//
//  asm("lis   %%r4, 0xffff;
//       ori   %%r4,%%r4,0x7fff;
//       mfmsr %%r3;
//       and   %%r3,%%r3,%%r4;
//       mtmsr %%r3"
//      : /* outputs */
//      : /* inputs */
//      : "%r3", "%r4" /* overwrites */
//     );

}

