
#include "interrupts.h"
#include "interruptutils.h"
#include "atomic.h"

static interrupt_handler_data_t handlers[MAX_INTERRUPT_HANDLERS];
static unsigned int idpos;

static void mpc5xx_ext_int_hdlr();

//INVARIANTS:
//handlers[i].used == 0       ==>  handlers[i].valid = 0
//  (or otherwise not ready)


void mpc5xx_init_ext_interrupts()
{
  int i;

  mpc5xx_disable_ext_interrupts();

  for (i = 0; i < MAX_INTERRUPT_HANDLERS; i++) {
    handlers[i].valid = 0;
    handlers[i].id = -1;
    handlers[i].used = 0;
  }

  idpos = 1;

  mpc5xx_install_interrupt_handler(MPC5XX_EXTERNAL_INTR, mpc5xx_ext_int_hdlr);

  //FIXME: This is temporary
  mpc5xx_install_interrupt_handler(MPC5XX_DECREMENTER_INTR, mpc5xx_ext_int_hdlr);
}

void mpc5xx_disable_ext_interrupts()
{
  mpc5xx_install_interrupt_handler(MPC5XX_EXTERNAL_INTR, null_interrupt_handler);
}

int mpc5xx_add_ext_interrupt_handler(interrupt_handler_t *hdlr)
{
  int i;
  int id;

  id = atomic_increment(&idpos, 1);

  for (i = 0; i < MAX_INTERRUPT_HANDLERS; i++) {
    if (atomic_compare_and_swap(&handlers[i].used, 0, -1))
      break;
  }

  if (i == MAX_INTERRUPT_HANDLERS) {
    //too many interrupt handlers
    return -1;
  }

  //note: handlers[i].valid == 0 by invariant

  handlers[i].fn = hdlr->fn;
  handlers[i].fnarg = hdlr->fnarg;
  handlers[i].id = id;
  handlers[i].used = 1;
  handlers[i].valid = 1;

  hdlr->id = id;
  hdlr->index = i;

  return 0;
}


int mpc5xx_remove_ext_interrupt_handler(interrupt_handler_t *hdlr)
{

  if (atomic_compare_and_swap(&handlers[hdlr->index].used, 1, -1)) {
    if (atomic_compare_and_swap(&handlers[hdlr->index].id, hdlr->id, -1)) {
      handlers[hdlr->index].valid = 0;
      handlers[hdlr->index].used = 0;
      return 0;
    }
    else {
      //the given index doesn't match id specified
      //set it back to used
      handlers[hdlr->index].used = 1;
      return -1;
    }
  }
  else
    return -1; //the given index wasn't even in use!

}


/* We don't have to worry about concurrency issues in this function because
 * it will _be_ the interrupt handler, and during its execution, interrupts
 * will be disabled (by the assembly that indirectly calls this function)
 */
static void mpc5xx_ext_int_hdlr()
{
  int i;

  for (i = 0; i < MAX_INTERRUPT_HANDLERS; i++) {
    if (!handlers[i].valid)
      continue;
    handlers[i].fn(handlers[i].fnarg);
  }
}


