#ifndef MPC5XX_IOBUFFERINTERRUPTS_H
#define MPC5XX_IOBUFFERINTERRUPTS_H

typedef enum { IOBUFFER_IN, IOBUFFER_OUT } iobuf_type_t;

typedef struct {
  /* user data portions */
  int size;
  void (*writefn)(char c); //fn that takes a char and writes it to the specific
                           //  module
                           //will only be called if readyfn() != 0
                           //ignored if an inbuffer
  char (*readfn)(); //fn that returns a char from the specific module
                    //will only be called if readyfn() != 0
                    //ignored if an outbuffer
  int (*readyfn)(); //should return 1     if more data is ready (if inbuffer)
                    //                 or if more data can be consumed (if
                    //                   outbuffer)
                    //              0 otherwise
  void (*disableintsfn)(); //fn that disables interrupts on the specific module
  void (*enableintsfn)(); //fn that enables interrupts on the specific module
  void (*ackfn)(); //fn that registers acknowledgement after receiving (if
                   //  inbuffer) or after sending (if outbuffer) data
  iobuf_type_t type; //IOBUFFER_IN or IOBUFFER_OUT

  /* internal data portions */
  char *buf;
  int readerlock;
  int inpos;
  int outpos;
  int intsactive;
  interrupt_handler_t inthandler;
} iobuffer_t;


int new_iobuffer(iobuffer_t *iobuf);
int delete_iobuffer(iobuffer_t *iobuf);
int iobuf_write(iobuffer_t *iobuf, char c);
int iobuf_read(iobuffer_t *iobuf);
void register_iobuffer_interrupts(iobuffer_t *iobuf);
void unregister_iobuffer_interrupts(iobuffer_t *iobuf);
void enable_iobuffer_interrupts(iobuffer_t *iobuf);
void disable_iobuffer_interrupts(iobuffer_t *iobuf);



#endif /* MPC5XX_IOBUFFERINTERRUPTS_H */

