// $Id: microseconds.c,v 1.1 2005/03/15 22:24:31 garthz Exp $ 
//
// Basic timing operations using the decrementer register.
#include <time.h>
#include <errno.h>

#include <mpc5xx/timestamps.h>
#include "microseconds.h"

/****************************************************************/
// A structure to hold the most recent computed time, and the 
// associated decrementer timestamp.

static microseconds_t current_time = 0;
static unsigned int current_decrementer;

/****************************************************************/
// Internal function to update the clock values.  Must be called at
// least once every 70 minutes or before the decrementer wraps all the
// way around.

static void update_current_time(void)
{
  unsigned int now = mpc5xx_read_DEC();
  int difference = current_decrementer - now;  // normally a positive value, register counts down

  // The decrementer register is 32 bits.  If treated as a unsigned
  // integer, it wraps around at 0x00000000 -> 0xffffffff.  If the current
  // and previous counter values are subtracted as unsigned ints
  // and the result cast to signed int, the differencing will work
  // correctly even at the wraparound.

  // E.g. 100 - 99          = 1          
  //        0 - 0xffffffff  = 1

#if DECREMENTER_RATE==1000000  
  current_time += difference;
#else
  current_time += difference * (1000000 / DECREMENTER_RATE);
#endif

  // save the new decrementer value for comparison later
  current_decrementer = now;
}

/****************************************************************/

microseconds_t usec_gettime ( void )
{
  update_current_time();
  return current_time;
}

void usec_settime ( microseconds_t value )
{
  current_decrementer = mpc5xx_read_DEC();  // capture decrementer value
  current_time = value;
}


/****************************************************************/
// Sleep until the given time value.
void usec_sleep_until( microseconds_t timestamp )
{
  do {
    update_current_time();

  } while ( current_time < timestamp );
}

