
#include <Motorola/m_qadc64.h>
#include "qadc64.h"

void mpc5xx_init_qadc64(struct QADC64_tag *qadc64)
{

  //Allow access to QADC64 registers in user mode
  qadc64->QADC64MCR.B.SUPV = 0;

  //Set the interrupt level to 0
  //  (is this disabled or just lowest priority?)
  qadc64->QADC64INT.B.IRL1 = 0;
  qadc64->QADC64INT.B.IRL2 = 0;

  //Enable internal multiplexing
  qadc64->QACR0.B.MUX = 0;

  //Settings for queue 1 (QACR1 register)
  qadc64->QACR1.B.CIE1 = 0; //disable completion interrupts
  qadc64->QACR1.B.PIE1 = 0; //disable pause interrupts
  qadc64->QACR1.B.MQ1 = 0; //queue disabled

  //Settings for queue 2 (QACR2 register)
  qadc64->QACR2.B.CIE2 = 0; //disable completion interrupts
  qadc64->QACR2.B.PIE2 = 0; //disable pause interrupts
  qadc64->QACR2.B.MQ2 = 0; //queue disabled
  qadc64->QACR2.B.BQ2 = 32; //queue 2 begins at position 32 in the CCW table

}


int mpc5xx_configure_qadc64(qadc64_queue *q)
{
  int i;

  if (q->numchannels < 0 || q->numchannels > 32)
    return -1;

  if (q->queue_number == QADC64_QUEUE1) {
    q->qoffset = 0;
    q->qadc_module->QACR1.B.MQ1 = 1; //make it stop converting
  }
  else { //queue_number == QADC64_QUEUE2
    q->qoffset = 32;
    q->qadc_module->QACR2.B.MQ2 = 1; //make it stop converting
  }

  for (i = 0; i < q->numchannels; i++) {
    q->qadc_module->CCW[q->qoffset+i].B.P = 0; //don't pause after this queue item
    q->qadc_module->CCW[q->qoffset+i].B.IST = q->channel[i].sample_time;
#ifdef _QADC64E
    q->qadc_module->CCW[q->qoffset+i].B.REF = q->channel[i].vref;
#endif /* _QADC64E */
    q->qadc_module->CCW[q->qoffset+i].B.CHAN = q->channel[i].chan;
  }

  if (i < 32) {
    //The user-supplied queue doesn't fill the allocated portion of the CCW
    //  table; write a termination sentinel
    q->qadc_module->CCW[q->qoffset+i].R = 63;
  }

  mpc5xx_qadc64_update_mode(q);

  return 0;
}

void mpc5xx_shutdown_qadc64(struct QADC64_tag *qadc64)
{

  //Settings for queue 1 (QACR1 register)
  qadc64->QACR1.B.CIE1 = 0; //disable completion interrupts
  qadc64->QACR1.B.PIE1 = 0; //disable pause interrupts
  qadc64->QACR1.B.MQ1 = 0; //disable queue

  //Settings for queue 2 (QACR2 register)
  qadc64->QACR2.B.CIE2 = 0; //disable completion interrupts
  qadc64->QACR2.B.PIE2 = 0; //disable pause interrupts
  qadc64->QACR2.B.MQ2 = 0; //disable queue
  qadc64->QACR2.B.BQ2 = 32; //queue 2 begins at position 32 in the CCW table
}

//This is really only useful if the queue is set to single-scan mode
//If it's set to continous scan, I think this doesn't harm anything if run
int mpc5xx_qadc64_start_conversion(qadc64_queue *q)
{
  if (q->queue_number == QADC64_QUEUE1) {
    q->qadc_module->QACR1.B.SSE1 = 1;
  }
  else { //queue_number == QADC64_QUEUE2
    q->qadc_module->QACR2.B.SSE2 = 1;
  }

  return 0;
}

inline int mpc5xx_qadc64_iscomplete(qadc64_queue *q)
{
  if (q->queue_number == QADC64_QUEUE1) {
    return q->qadc_module->QASR0.B.CF1;
  }
  else { //queue_number == QADC64_QUEUE2
    return q->qadc_module->QASR0.B.CF2;
  }
}

inline int mpc5xx_qadc64_waitforcomplete(qadc64_queue *q)
{
  if (q->queue_number == QADC64_QUEUE1) {
    while (q->qadc_module->QASR0.B.CF1 == 0);
      //wait
  }
  else { //queue_number == QADC64_QUEUE2
    while (q->qadc_module->QASR0.B.CF2 == 0);
      //wait
  }

  return 0;
}

int mpc5xx_qadc64_update_mode(qadc64_queue *q)
{
  int flagval;

  switch (q->queue_mode) {
    case QADC64_MODE_DISABLED:
      flagval = QADC64_DISABLED_FLAG;
      break;
    case QADC64_MODE_SINGLE_SCAN:
      flagval = QADC64_SINGLE_SCAN_FLAG;
      break;
    case QADC64_MODE_CONTINUOUS_SCAN:
      flagval = QADC64_CONTINUOUS_SCAN_FLAG;
      break;
    default: //huh?!
      return -1;
      break;
  }

  if (q->queue_number == QADC64_QUEUE1) {
    q->qadc_module->QACR1.B.MQ1 = flagval;
  }
  else { //queue_number == QADC64_QUEUE2
    q->qadc_module->QACR2.B.MQ2 = flagval;
  }

  return 0;
}

