#ifndef MPC5XX_QADC64_H
#define MPC5XX_QADC64_H

typedef enum { QADC64_MODE_DISABLED = 0,
               QADC64_MODE_SINGLE_SCAN,
               QADC64_MODE_CONTINUOUS_SCAN } qadc64_queue_mode_t;

typedef enum { QADC64_QUEUE1 = 1,
               QADC64_QUEUE2 = 2 } qadc64_queue_num_t;

#define QADC64_16_CYCLES 1
#define QADC64_2_CYCLES  0

typedef struct {
  struct QADC64_tag *qadc_module;
  qadc64_queue_num_t queue_number;
  qadc64_queue_mode_t queue_mode;
  int numchannels; //[0,32]
  struct {
    int sample_time:1; //1 => 16 QCLK cycles, 0 => 2 QCLK cycles
#ifdef _QADC64E
    int vref:1; //QADC64_INT_VREF or QADC64_EXT_VREF
#endif /* _QADC64E */
    int chan:7;
  } channel[32];
  int qoffset; //(not set by user application)
} qadc64_queue;


//QADC64_GET_RESULT(struct qadc64_queue *q, int index)
//q is a queue structure as defined above
//index is the array index (of the channel[] array) corresponding to the ADC
//  channel whose conversion result is desired
#define QADC64_GET_RESULT(q, index) ((q)->qadc_module->RJURR[(q)->qoffset+(index)].R)

#ifdef _QADC64E
#define QADC64_INT_VREF 0
#define QADC64_EXT_VREF 1
#endif /* _QADC64E */


void mpc5xx_init_qadc64(struct QADC64_tag *qadc64);
int mpc5xx_configure_qadc64(qadc64_queue *q);
void mpc5xx_shutdown_qadc64(struct QADC64_tag *qadc64);

int mpc5xx_qadc64_start_conversion(qadc64_queue *q);
int mpc5xx_qadc64_update_mode(qadc64_queue *q);

inline int mpc5xx_qadc64_iscomplete(qadc64_queue *q);
inline int mpc5xx_qadc64_waitforcomplete(qadc64_queue *q);

/*** Stuff internal to qadc64.c ***/

#define QADC64_DISABLED_FLAG 0
#define QADC64_SINGLE_SCAN_FLAG 1
#define QADC64_CONTINUOUS_SCAN_FLAG 17

#endif /* MPC5XX_QADC64_H */

