// $Id: phyCORE_MPC565.h,v 1.3 2004/05/17 15:26:44 garthz Exp $
#ifndef _PHYCORE_MPC565_H_DEFINED_
#define _PHYCORE_MPC565_H_DEFINED_

#ifndef UINT32
#include <Motorola/m_common.h>  // for integer types
#endif

//================================================================
// Some information about the configuration.

// #define SYSTEM_CLOCK     20000000             // in Hz
#define SYSTEM_CLOCK     40000000             // in Hz
#define DECREMENTER_RATE  1000000             // in Hz  // This depends on the current time base clock init code.
#define TPU_CLOCK_RATE    (SYSTEM_CLOCK / 32) // in Hz  // This depends on the current TPU init code.

// Memory map
#define PHY_C3F_FLASH_BASE 0x00000000         // two internal MPC565 UC3F flash arrays
#define PHY_C3F_FLASH_SIZE 0x00100000         // 1 M in two 512K segments
#define PHY_SRAM_BASE      0x01000000
#define PHY_SRAM_SIZE      0x00200000         // size in bytes
#define PHY_STD_FLASH_BASE 0x02000000
#define PHY_STD_FLASH_SIZE 0x00200000         // size in bytes

//================================================================
// Initialize some hardware.  This should only be called once.
extern void phyCORE_MPC565_init(void);

// Set the state of the indicator LED.
extern void phyCORE_MPC565_set_LED(int flag);

// Initialize the serial port.
//  qsmcm = 0 for QSMCM_A, 1 for QSMCM_B
//  sci = 0 for SCI1, 1 for SCI2
extern void phyCORE_MPC565_init_serial( int qsmcm, int sci );

//================ General MPC5xx utility functions =====================
// Read the IMMR, Internal Memory Map Register.
// The fields are as follows
// names:  PARTNUM : MASKNUM : RESERVED : FLEN : RESERVED : RESERVED : RESERVED : ISB : 0
// widths:      8       8         4         1       2           1         4        3    1
//
// Define a few masks for the value:
#define MPC5XX_IMMR_PARTNUM_MASK   (0xff000000) 
#define MPC5XX_IMMR_MASKNUM_MASK   (0x00ff0000)
#define MPC5XX_IMMR_FLEN_MASK      (0x00000800)    // enables the internal flash (1 == enabled)
#define MPC5XX_IMMR_ISB_MASK       (0x0000000e)    // base address of internal registers = (ISB * 0x40000)

// Just for reference, my MPC565 is starting up with 0x33110800.
extern UINT32 mpc5xx_read_IMMR(void);


// Read the DEC, Decrementer register, SPR 22.
extern UINT32 mpc5xx_read_DEC(void);

//================================================================
#endif
